@@ -295,6 +295,13 @@ class TreeBeat(object):
             elif chord.quarter_duration == Fraction(25, 1):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 17)
+            elif chord.quarter_duration == Fraction(1, 2):
+                if chord.position_in_beat == Fraction(1, 8):
+                    split = chord.split(3, 1)
+                elif chord.position_in_beat == Fraction(2, 8):
+                    split = chord.split(1, 1)
+                elif chord.position_in_beat == Fraction(3, 8):
+                    split = chord.split(1, 3)
             elif chord.quarter_duration == Fraction(3, 2):
                 if chord.position_in_beat == 0.5:
                     split = chord.split(1, 2)
@@ -311,19 +318,22 @@ class TreeBeat(object):
             elif chord.quarter_duration == Fraction(9, 2):
                 if chord.position_in_beat == 0:
                     split = chord.split(8, 1)
-
             elif chord.quarter_duration == Fraction(1, 4):
                 if chord.position_in_beat == Fraction(3, 8):
                     split = chord.split(1, 1)
+            elif chord.quarter_duration == Fraction(3, 4):
+                if chord.position_in_beat == Fraction(1, 8):
+                    split = chord.split(3, 3)
             elif chord.quarter_duration == Fraction(3, 8):
-                if chord.position_in_beat == Fraction(3, 8):
+                if chord.position_in_beat == Fraction(2, 8):
+                    split = chord.split(2, 1)
+                elif chord.position_in_beat == Fraction(3, 8):
                     split = chord.split(1, 2)
             elif chord.quarter_duration == Fraction(5, 6) and self.best_div == 6:
                 if chord.position_in_beat == Fraction(0, 6):
                     split = chord.split(4, 1)
                 elif chord.position_in_beat == Fraction(1, 6):
                     split = chord.split(1, 4)
-
             elif chord.quarter_duration == Fraction(5, 7):
                 if chord.position_in_beat == Fraction(0, 7):
                     split = chord.split(3, 2)
@@ -331,7 +341,6 @@ class TreeBeat(object):
                     split = chord.split(3, 2)
                 elif chord.position_in_beat == Fraction(2, 7):
                     split = chord.split(2, 3)
-
             elif chord.quarter_duration == Fraction(5, 8):
                 if chord.position_in_beat == Fraction(0, 8):
                     split = chord.split(4, 1)
