@@ -9,22 +9,34 @@ from musicscore.musicxml.types.complextypes.scorepart import PartName, PartAbbre
 class TreeInstrument(ComplexTypeMidiInstrument):
     _TAG = 'midi-instrument'
 
-    def __init__(self, name, abbreviation=None, number=None, *args, **kwargs):
+    def __init__(self, name, number_of_staves=None, abbreviation=None, number=None, *args, **kwargs):
         super().__init__(tag=self._TAG, id_='inst' + str(uuid.uuid4()), *args, **kwargs)
         self._part_name = PartName(name=name)
         self._part_abbreviation = PartAbbreviation()
-        self._standard_clef = None
+        self._number_of_staves = None
+        self._standard_clefs = None
         self._number = None
+
+        self.number_of_staves = number_of_staves
         self.abbreviation = abbreviation
         self.number = number
 
+    # public properties
     @property
-    def part_name(self):
-        return self._part_name
+    def abbreviation(self):
+        return self._part_abbreviation.value
+
+    @abbreviation.setter
+    def abbreviation(self, val):
+        self._part_abbreviation.value = val
 
     @property
-    def part_abbreviation(self):
-        return self._part_abbreviation
+    def name(self):
+        return self._part_name.name
+
+    @name.setter
+    def name(self, val):
+        self._part_name.name = val
 
     @property
     def number(self):
@@ -44,32 +56,43 @@ class TreeInstrument(ComplexTypeMidiInstrument):
             self.abbreviation += ' ' + str(self._number)
 
     @property
-    def name(self):
-        return self._part_name.name
-
-    @name.setter
-    def name(self, val):
-        self._part_name.name = val
+    def part_name(self):
+        return self._part_name
 
     @property
-    def abbreviation(self):
-        return self._part_abbreviation.value
-
-    @abbreviation.setter
-    def abbreviation(self, val):
-        self._part_abbreviation.value = val
+    def part_abbreviation(self):
+        return self._part_abbreviation
 
     @property
-    def standard_clef(self):
-        return self._standard_clef
+    def standard_clefs(self):
+        return self._standard_clefs
 
-    @standard_clef.setter
-    def standard_clef(self, val):
-        if val and not isinstance(val, TreeClef):
-            raise TypeError('standard_clef.value must be of type TreeClef not{}'.format(type(val)))
-        self._standard_clef = val
+    @standard_clefs.setter
+    def standard_clefs(self, vals):
+        if not hasattr(vals, '__iter__'):
+            vals = [vals]
+        for index, val in enumerate(vals):
+            if not isinstance(val, TreeClef):
+                raise TypeError('standard_clef.value must be of type TreeClef not{}'.format(type(val)))
+            vals[index] = val.__deepcopy__()
+
+        if len(vals) > 1:
+            for index, val in enumerate(vals):
+                val.number = index + 1
+        self._standard_clefs = vals
+
+    @property
+    def number_of_staves(self):
+        return self._number_of_staves
+
+    @number_of_staves.setter
+    def number_of_staves(self, val):
+        if val is not None and not isinstance(val, int):
+            raise TypeError('number_of_staves.value must be of type int not{}'.format(type(val)))
+        self._number_of_staves = val
 
 
+# strings
 class String(object):
     def __init__(self, number, tuning, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -93,6 +116,77 @@ class String(object):
         return step
 
 
+class StringInstrument(TreeInstrument):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.strings = {}
+
+
+class Violin(StringInstrument):
+    def __init__(self, number=None, *args, **kwargs):
+        super().__init__(name='Violin', abbreviation='vln.', number=number, *args, **kwargs)
+        self.strings = {4: String(4, G(3)),
+                        3: String(3, D(4)),
+                        2: String(2, A(4)),
+                        1: String(1, E(5))
+                        }
+        self.standard_clefs = TREBLE_CLEF
+
+
+class Viola(StringInstrument):
+    def __init__(self, number=None, *args, **kwargs):
+        super().__init__(name='Viola', abbreviation='vla.', number=number, *args, **kwargs)
+        self.strings = {4: String(4, C(3)),
+                        3: String(3, G(3)),
+                        2: String(2, D(4)),
+                        1: String(1, A(4))
+                        }
+        self.standard_clefs = ALTO_CLEF
+
+
+class Cello(StringInstrument):
+    def __init__(self, number=None, *args, **kwargs):
+        super().__init__(name='Cello', abbreviation='vc.', number=number, *args, **kwargs)
+        self.strings = {4: String(4, C(2)),
+                        3: String(3, G(2)),
+                        2: String(2, D(3)),
+                        1: String(1, A(3))
+                        }
+        self.standard_clefs = BASS_CLEF
+
+
+class ViolaDamore(StringInstrument):
+    def __init__(self, number=None, *args, **kwargs):
+        super().__init__(name='Viola d\'amore\n430', abbreviation='vla.', number=number, *args, **kwargs)
+        # skordatura
+        self.strings = {1: String(1, B(4)),
+                        2: String(2, B(4)),
+                        3: String(3, F(4, '#')),
+                        4: String(4, C(4)),
+                        5: String(5, G(3)),
+                        6: String(6, D(3)),
+                        7: String(7, A(2))
+                        }
+
+
+# keyboards
+class KeyboardInstrument(TreeInstrument):
+    def __init__(self, number_of_staves=2, *args, **kwargs):
+        super().__init__(number_of_staves=number_of_staves, *args, **kwargs)
+        self.standard_clefs = [TREBLE_CLEF, BASS_CLEF]
+
+
+class Accordion(KeyboardInstrument):
+    def __init__(self, number=None, *args, **kwargs):
+        super().__init__(name='Accordion', abbreviation='acc.', number=number, *args, **kwargs)
+
+
+class Piano(KeyboardInstrument):
+    def __init__(self, *args, **kwargs):
+        super().__init__(name='Piano', abbreviation='pno.', *args, **kwargs)
+
+
+# brass
 class NaturalInstrument(TreeInstrument):
 
     def __init__(self, key, a4=440, *args, **kwargs):
@@ -145,64 +239,6 @@ class NaturalInstrument(TreeInstrument):
         return frequency_to_midi(self.get_fundamental_frequency() * number, self.a4)
 
 
-class StringInstrument(TreeInstrument):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-        self.strings = {}
-
-
-class Violin(StringInstrument):
-    def __init__(self, number=None, *args, **kwargs):
-        super().__init__(name='Violin', abbreviation='vln.', number=number, *args, **kwargs)
-        self.strings = {4: String(4, G(3)),
-                        3: String(3, D(4)),
-                        2: String(2, A(4)),
-                        1: String(1, E(5))
-                        }
-        self.standard_clef = TREBLE_CLEF
-
-
-class Viola(StringInstrument):
-    def __init__(self, number=None, *args, **kwargs):
-        super().__init__(name='Viola', abbreviation='vla.', number=number, *args, **kwargs)
-        self.strings = {4: String(4, C(3)),
-                        3: String(3, G(3)),
-                        2: String(2, D(4)),
-                        1: String(1, A(4))
-                        }
-        self.standard_clef = ALTO_CLEF
-
-
-class Cello(StringInstrument):
-    def __init__(self, number=None, *args, **kwargs):
-        super().__init__(name='Cello', abbreviation='vc.', number=number, *args, **kwargs)
-        self.strings = {4: String(4, C(2)),
-                        3: String(3, G(2)),
-                        2: String(2, D(3)),
-                        1: String(1, A(3))
-                        }
-        self.standard_clef = BASS_CLEF
-
-
-class ViolaDamore(StringInstrument):
-    def __init__(self, number=None, *args, **kwargs):
-        super().__init__(name='Viola d\'amore\n430', abbreviation='vla.', number=number, *args, **kwargs)
-        # skordatura
-        self.strings = {1: String(1, B(4)),
-                        2: String(2, B(4)),
-                        3: String(3, F(4, '#')),
-                        4: String(4, C(4)),
-                        5: String(5, G(3)),
-                        6: String(6, D(3)),
-                        7: String(7, A(2))
-                        }
-
-
-class Accordion(TreeInstrument):
-    def __init__(self, number=None, *args, **kwargs):
-        super().__init__(name='Accordion', abbreviation='acc.', number=number, *args, **kwargs)
-
-
 class Horn(TreeInstrument):
     def __init__(self, number=None, *args, **kwargs):
         super().__init__(name='Horn', abbreviation='hrn.', number=number, *args, **kwargs)
@@ -214,6 +250,18 @@ class NaturalHorn(NaturalInstrument):
         self.transposition = 9
 
 
+# percussion
+class Percussion(TreeInstrument):
+    def __init__(self, number=None, *args, **kwargs):
+        super().__init__(name='Percussion', abbreviation='perc.', number=number, *args, **kwargs)
+        self.tamtam = TamTam()
+        self.cymbal_1 = Cymbal(1)
+        self.cymbal_2 = Cymbal(2)
+        self.cymbal_3 = Cymbal(3)
+        self.cymbal_4 = Cymbal(4)
+        self.cymbal_5 = Cymbal(5)
+
+
 class TamTam(TreeInstrument):
     def __init__(self, number=None, *args, **kwargs):
         super().__init__(name='Tam-tam', abbreviation='Tam-t.', number=number, *args, **kwargs)
@@ -232,12 +280,7 @@ class Cymbal(TreeInstrument):
         self.midi.notehead = 'x'
 
 
-class Percussion(TreeInstrument):
-    def __init__(self, number=None, *args, **kwargs):
-        super().__init__(name='Percussion', abbreviation='perc.', number=number, *args, **kwargs)
-        self.tamtam = TamTam()
-        self.cymbal_1 = Cymbal(1)
-        self.cymbal_2 = Cymbal(2)
-        self.cymbal_3 = Cymbal(3)
-        self.cymbal_4 = Cymbal(4)
-        self.cymbal_5 = Cymbal(5)
+# voice
+class Voice(TreeInstrument):
+    def __init__(self, *args, **kwargs):
+        super().__init__(name='voice', abbreviation='v.', *args, **kwargs)
