@@ -31,6 +31,7 @@ class TreePartVoice(object):
         self._forbidden_divisions = None
         self._chords = []
         self._beats = []
+        self._break_beam_32 = None
         self._filled_with_rest = False
         self._preliminary_rests_adjoined = False
         self._beats_added = False
@@ -170,6 +171,20 @@ class TreePartVoice(object):
 
         self._forbidden_divisions = value
 
+    @property
+    def break_beam_32(self):
+        if self._break_beam_32 is None:
+            self._break_beam_32 = self.parent_part.break_beam_32
+
+        return self._break_beam_32
+
+    @break_beam_32.setter
+    def break_beam_32(self, value):
+        if value is not None:
+            if not isinstance(value, bool):
+                raise TypeError(f'Score().break_beam_32 {value} must be boolean.')
+        self._break_beam_32 = value
+
     @property
     def max_division(self):
         if self._max_division is None:
@@ -555,7 +570,26 @@ class TreePartVoice(object):
                         grouping_list.append(1)
             return grouping_list
 
-        def _set_beams(grouped_chords):
+        def _set_break_beams():
+            def _get_relevant_beams(chord):
+                return [beam for beam in chord.get_children_by_type(Beam) if
+                        beam.number > 1 and beam.value == 'continue']
+
+            if self.break_beam_32:
+                for gr in grouped_chords:
+                    try:
+                        quaver_positioned_chord = [chord for chord in gr if chord.offset == 0.5][0]
+                        previous_chord = gr[gr.index(quaver_positioned_chord) - 1]
+                        for beam in _get_relevant_beams(quaver_positioned_chord):
+                            beam.value = 'begin'
+                        for beam in _get_relevant_beams(previous_chord):
+                            beam.value = 'end'
+                    except IndexError:
+                        pass
+            else:
+                pass
+
+        def _set_beams():
 
             global begin_beam, continue_end_beam
 
@@ -608,7 +642,8 @@ class TreePartVoice(object):
         if grouping_list is None:
             grouping_list = _generate_grouping_list()
             grouped_chords = self._group_beats(grouping_list)
-            _set_beams(grouped_chords)
+            _set_beams()
+            _set_break_beams()
         else:
             raise NotImplementedError('group_beams with values other than None')
 
@@ -1006,6 +1041,7 @@ class TreePart(timewise.Part):
         super().__init__(*args, **kwargs)
         attributes = self.add_child(Attributes())
         attributes.add_child(Divisions(1))
+        self._break_beam_32 = None
         self._max_division = None
         self._forbidden_divisions = None
         self._tree_part_staves = {}
@@ -1061,6 +1097,23 @@ class TreePart(timewise.Part):
 
         self._forbidden_divisions = value
 
+    @property
+    def break_beam_32(self):
+        if self._break_beam_32 is None:
+            if self.parent_score_part:
+                self._break_beam_32 = self.parent_score_part.parent_score.break_beam_32
+            else:
+                return None
+
+        return self._break_beam_32
+
+    @break_beam_32.setter
+    def break_beam_32(self, value):
+        if value is not None:
+            if not isinstance(value, bool):
+                raise TypeError(f'TreePart().break_beam_32 {value} must be boolean.')
+        self._break_beam_32 = value
+
     @property
     def max_division(self):
         if self._max_division is None:
