@@ -36,6 +36,7 @@ class TreeScoreTimewise(timewise.Score):
         self._forbidden_divisions = None
         self._page_style = TreePageStyle(score=self, **kwargs)
         self._accidental_mode = 'normal'
+        self._break_beam_32 = False
         self._title = None
         self._subtitle = None
         self._composer = None
@@ -78,6 +79,16 @@ class TreeScoreTimewise(timewise.Score):
     def accidental_mode(self, value):
         self._accidental_mode = value
 
+    @property
+    def break_beam_32(self):
+        return self._break_beam_32
+
+    @break_beam_32.setter
+    def break_beam_32(self, value):
+        if not isinstance(value, bool):
+            raise TypeError(f'Score().break_beam_32 {value} must be boolean.')
+        self._break_beam_32 = value
+
     @property
     def composer(self):
         return self._composer
