@@ -29,6 +29,15 @@ class Test(TestCase):
     <voice>2</voice>
     <type>whole</type>
   </note>
+  <backup>
+    <duration>4</duration>
+  </backup>
+  <note>
+    <rest/>
+    <duration>4</duration>
+    <voice>1</voice>
+    <type>whole</type>
+  </note>
 </part>
 '''
         self.assertEqual(p.to_string(), result)
@@ -58,6 +67,15 @@ class Test(TestCase):
       <tied number="1" type="start"/>
     </notations>
   </note>
+  <backup>
+    <duration>4</duration>
+  </backup>
+  <note>
+    <rest/>
+    <duration>4</duration>
+    <voice>1</voice>
+    <type>whole</type>
+  </note>
 </part>
 '''
         self.assertEqual(p.to_string(), result)
@@ -92,6 +110,15 @@ class Test(TestCase):
     <voice>2</voice>
     <type>quarter</type>
   </note>
+  <backup>
+    <duration>4</duration>
+  </backup>
+  <note>
+    <rest/>
+    <duration>4</duration>
+    <voice>1</voice>
+    <type>whole</type>
+  </note>
 </part>
 '''
         self.assertEqual(p.to_string(), result)
@@ -113,6 +140,15 @@ class Test(TestCase):
     <voice>2</voice>
     <type>whole</type>
   </note>
+  <backup>
+    <duration>4</duration>
+  </backup>
+  <note>
+    <rest/>
+    <duration>4</duration>
+    <voice>1</voice>
+    <type>whole</type>
+  </note>
 </part>
 '''
         self.assertEqual(p.to_string(), result)
@@ -136,6 +172,15 @@ class Test(TestCase):
     <voice>2</voice>
     <type>whole</type>
   </note>
+  <backup>
+    <duration>4</duration>
+  </backup>
+  <note>
+    <rest/>
+    <duration>4</duration>
+    <voice>1</voice>
+    <type>whole</type>
+  </note>
 </part>
 '''
         self.assertEqual(p.to_string(), result)
