@@ -14,7 +14,7 @@ class TestTreeChord(TestCase):
         self.chord = TreeChord((60, 61), quarter_duration=2)
 
     def test_chord(self):
-        for tree_note in self.chord._notes:
+        for tree_note in self.chord.notes:
             tree_note.update_duration(divisions=1)
             # print(tree_note.to_string())
 
@@ -23,7 +23,7 @@ class TestTreeChord(TestCase):
             TreeChord((0, 61), quarter_duration=2)
 
         chord = TreeChord(0, quarter_duration=2)
-        tree_note = chord._notes[0]
+        tree_note = chord.notes[0]
         tree_note.update_duration(divisions=1)
 
         result = '''<note>
@@ -35,7 +35,7 @@ class TestTreeChord(TestCase):
 
     def test_chord_midi(self):
         chord = TreeChord(Midi(63, accidental = Accidental(mode='sharp')), quarter_duration=2)
-        tree_note = chord._notes[0]
+        tree_note = chord.notes[0]
         tree_note.update_duration(divisions=1)
 
         result = '''<note>
